@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals, absolute_import
 
-"""Useful decorators."""
-
+"""
+Useful decorators.
+"""
 
+import sys
 from functools import wraps
 
 from django.conf import settings
@@ -13,13 +16,20 @@ from django.http import (
 from twilio.twiml import Verb
 from twilio.util import RequestValidator
 
-from django_twilio import settings as django_twilio_settings
-from django_twilio.utils import get_blacklisted_response
+from .settings import TWILIO_AUTH_TOKEN
+from .utils import get_blacklisted_response
+
+
+# Snippet from the `six` library to help with Python3 compatibility
+if sys.version_info[0] == 3:
+    text_type = str
+else:
+    text_type = unicode
 
 
 def twilio_view(f):
-    """This decorator provides several helpful shortcuts for writing Twilio
-    views.
+    """
+    This decorator provides several helpful shortcuts for writing Twilio views.
 
         - It ensures that only requests from Twilio are passed through. This
           helps protect you from forged requests.
@@ -32,7 +42,7 @@ def twilio_view(f):
           blacklisted, any requests from them will be rejected.
 
         - It allows your view to (optionally) return TwiML to pass back to
-          Twilio's servers instead of building a ``HttpResponse`` object
+          Twilio's servers instead of building an ``HttpResponse`` object
           manually.
 
         - It allows your view to (optionally) return any ``twilio.Verb`` object
@@ -44,30 +54,34 @@ def twilio_view(f):
 
     Usage::
 
-        from twilio.twiml import Response
+        from twilio import twiml
 
         @twilio_view
         def my_view(request):
-            r = Response()
+            r = twiml.Response()
             r.message('Thanks for the SMS message!')
             return r
     """
     @csrf_exempt
     @wraps(f)
-    def decorator(request_or_self, methods=['POST'],
+    def decorator(request_or_self, methods=('POST',),
                   blacklist=True, *args, **kwargs):
 
-        class_based_view = not(isinstance(request_or_self, HttpRequest))
+        class_based_view = not isinstance(request_or_self, HttpRequest)
         if not class_based_view:
             request = request_or_self
         else:
             assert len(args) >= 1
             request = args[0]
 
-        # Turn off Twilio authentication when explicitly requested, or in debug mode.
-        # Otherwise things do not work properly. For more information see the docs.
-        use_forgery_protection = (
-            getattr(settings, 'DJANGO_TWILIO_FORGERY_PROTECTION', not settings.DEBUG))
+        # Turn off Twilio authentication when explicitly requested, or
+        # in debug mode. Otherwise things do not work properly. For
+        # more information, see the docs.
+        use_forgery_protection = getattr(
+            settings,
+            'DJANGO_TWILIO_FORGERY_PROTECTION',
+            not settings.DEBUG,
+        )
         if use_forgery_protection:
 
             if request.method not in methods:
@@ -75,8 +89,7 @@ def twilio_view(f):
 
             # Forgery check
             try:
-                validator = RequestValidator(
-                    django_twilio_settings.TWILIO_AUTH_TOKEN)
+                validator = RequestValidator(TWILIO_AUTH_TOKEN)
                 url = request.build_absolute_uri()
                 signature = request.META['HTTP_X_TWILIO_SIGNATURE']
             except (AttributeError, KeyError):
@@ -90,16 +103,19 @@ def twilio_view(f):
                     return HttpResponseForbidden()
 
         # Blacklist check
-        checkBlackList = (
-            getattr(settings, 'DJANGO_TWILIO_BLACKLIST_CHECK', blacklist))
-        if checkBlackList:
+        check_blacklist = getattr(
+            settings,
+            'DJANGO_TWILIO_BLACKLIST_CHECK',
+            blacklist
+        )
+        if check_blacklist:
             blacklisted_resp = get_blacklisted_response(request)
             if blacklisted_resp:
                 return blacklisted_resp
 
         response = f(request_or_self, *args, **kwargs)
 
-        if isinstance(response, str):
+        if isinstance(response, (text_type, bytes)):
             return HttpResponse(response, content_type='application/xml')
         elif isinstance(response, Verb):
             return HttpResponse(str(response), content_type='application/xml')
